@@ -9,12 +9,13 @@
 
 require 'mmon/item'
 require 'mmon/util'
+require 'mmon/label'
 
 class ItemDClock < Item
-    include Math
-
     NAME = 'Digital Clock'
 
+    @@color_text = Color.new(1.0, 1.0, 0.0, 1.0)
+
     def initialize(parent = nil)
         super(parent)
 
@@ -23,6 +24,9 @@ class ItemDClock < Item
         self.set_item_size(72, 32)
 
         @now = Time.now
+
+        @label = Label.new(nil, 16, false, true, @@color_text, 0.5 * @width, 0.5 * @height)
+        @label.text = @now.strftime('%H:%M') 
     end
 
     private
@@ -38,20 +42,7 @@ class ItemDClock < Item
     end
 
     def render(cc, w, h)
-        text = @now.strftime('%H:%M') 
-
-#        cc.select_font_face("Sans", Cairo::FONT_SLANT_NORMAL, Cairo::FONT_WEIGHT_BOLD);
-        cc.select_font_face("Bitstream Vera Sans", Cairo::FONT_SLANT_NORMAL, Cairo::FONT_WEIGHT_BOLD);
-        cc.set_source_rgba(1.0, 1.0, 0.0, 1.0);
-        cc.set_font_size(h * 0.5)
-
-        extents = cc.text_extents(text)
-
-        x = w / 2.0 - (extents.width / 2.0) - (extents.x_bearing / 2.0)
-        y = h / 2.0 + extents.height / 2.0
-    
-        cc.move_to(x, y)
-        cc.show_text(text);
+        @label.render(cc)
     end
 
     def prepare
@@ -61,6 +52,7 @@ class ItemDClock < Item
         if @now.min == old.min
             return false
         else
+            @label.text = @now.strftime('%H:%M') 
             return true
         end
     end
